@@ -87,6 +87,48 @@ static GParamSpec *properties [LAST_PROP];
 
 #ifdef HAVE_CLOUDPROVIDERS
 
+static void
+dummy_callback (NautilusFile *file,
+                gpointer      callback_data)
+{
+  /* No-op. Just a tag for nautilus_file_cancel_call_when_ready() to match. */
+}
+
+static void
+on_file_changed (NautilusGtkSidebarRow *self)
+{
+  g_return_if_fail (NAUTILUS_IS_GTK_SIDEBAR_ROW (self));
+  g_return_if_fail (NAUTILUS_IS_FILE (self->file));
+  if (nautilus_file_is_gone (self->file))
+    {
+      g_signal_handlers_disconnect_by_func (self->file, on_file_changed, self);
+      nautilus_file_cancel_call_when_ready (self->file, dummy_callback, self);
+      g_clear_object (&self->file);
+    }
+}
+
+static void
+ensure_connected_file (NautilusGtkSidebarRow *self)
+{
+  if (self->file != NULL)
+    return;
+
+  if (self->uri != NULL)
+    {
+      g_autoptr (NautilusFile) file = nautilus_file_get_by_uri (self->uri);
+
+      /* Self-owned file may be marked as gone, if we are rebuilding the sidebar
+       * in response to that file being unmounted. Don't keep it alive. */
+      if (file == NULL || nautilus_file_is_gone (file))
+        return;
+
+      self->file = g_steal_pointer (&file);
+      nautilus_file_call_when_ready (self->file, NAUTILUS_FILE_ATTRIBUTE_MOUNT, dummy_callback, self);
+      g_signal_connect_object (self->file, "changed",
+                               G_CALLBACK (on_file_changed), self, G_CONNECT_SWAPPED);
+    }
+}
+
 static void
 cloud_row_update (NautilusGtkSidebarRow *self)
 {
@@ -185,6 +227,7 @@ nautilus_gtk_sidebar_row_get_property (GObject    *object,
       break;
 
     case PROP_NAUTILUS_FILE:
+      ensure_connected_file (self);
       g_value_set_object (value, self->file);
       break;
 
@@ -307,12 +350,7 @@ nautilus_gtk_sidebar_row_set_property (GObject      *object,
     case PROP_URI:
       g_free (self->uri);
       self->uri = g_strdup (g_value_get_string (value));
-      if (self->uri != NULL)
-        {
-          self->file = nautilus_file_get_by_uri (self->uri);
-          if (self->file != NULL)
-            nautilus_file_call_when_ready (self->file, NAUTILUS_FILE_ATTRIBUTE_MOUNT, NULL, NULL);
-        }
+      ensure_connected_file (self);
       break;
 
     case PROP_DRIVE:
