@@ -29,6 +29,7 @@
 #include "nautilus-metadata.h"
 #include "nautilus-file.h"
 #include "nautilus-file-operations.h"
+#include "nautilus-scheme.h"
 #include "nautilus-search-directory.h"
 #include "nautilus-starred-directory.h"
 #include "nautilus-ui-utilities.h"
@@ -471,55 +472,11 @@ nautilus_is_root_directory (GFile *dir)
 }
 
 gboolean
-nautilus_is_search_directory (GFile *dir)
+nautilus_is_root_for_scheme (GFile      *dir,
+                             const char *scheme)
 {
-    g_autofree gchar *uri = NULL;
-
-    uri = g_file_get_uri (dir);
-    return eel_uri_is_search (uri);
-}
-
-gboolean
-nautilus_is_recent_directory (GFile *dir)
-{
-    g_autofree gchar *uri = NULL;
-
-    uri = g_file_get_uri (dir);
-
-    return eel_uri_is_recent (uri);
-}
-
-gboolean
-nautilus_is_starred_directory (GFile *dir)
-{
-    g_autofree gchar *uri = NULL;
-
-    uri = g_file_get_uri (dir);
-
-    if (eel_uri_is_starred (uri))
-    {
-        return TRUE;
-    }
-
-    return FALSE;
-}
-
-gboolean
-nautilus_is_trash_directory (GFile *dir)
-{
-    g_autofree gchar *uri = NULL;
-
-    uri = g_file_get_uri (dir);
-    return eel_uri_is_trash (uri);
-}
-
-gboolean
-nautilus_is_other_locations_directory (GFile *dir)
-{
-    g_autofree gchar *uri = NULL;
-
-    uri = g_file_get_uri (dir);
-    return eel_uri_is_other_locations (uri);
+    return (g_file_has_uri_scheme (dir, scheme) &&
+            !g_file_has_parent (dir, NULL));
 }
 
 GMount *
@@ -530,13 +487,14 @@ nautilus_get_mounted_mount_for_root (GFile *location)
     GList *l;
     GMount *mount;
     GMount *result = NULL;
-    GFile *root = NULL;
 
     volume_monitor = g_volume_monitor_get ();
     mounts = g_volume_monitor_get_mounts (volume_monitor);
 
     for (l = mounts; l != NULL; l = l->next)
     {
+        g_autoptr (GFile) root = NULL;
+
         mount = l->data;
 
         if (g_mount_is_shadowed (mount))
@@ -552,7 +510,6 @@ nautilus_get_mounted_mount_for_root (GFile *location)
         }
     }
 
-    g_clear_object (&root);
     g_list_free_full (mounts, g_object_unref);
 
     return result;
